==> Iacorner_0.22_dev.zip: an/db/postgres/sql/01_TABLE/AN04S.sql <==
/**************************************************************************/
/* AN04 ( 主催者マスタ )                                                  */
/*                                                                        */
/* Created : 2010/09/27 16:41:33                                          */
/**************************************************************************/
CREATE TABLE AN04 (
   USERID   VARCHAR(10)                  NOT NULL                 /* 1  ユーザーID     */
 , PASSWD   VARCHAR(20)                  NOT NULL                 /* 2  パスワード     */
 , ROLES    VARCHAR(500)                 NOT NULL                 /* 3  ロールズ       */
 , NAME_JA  VARCHAR(500)                 NOT NULL                 /* 4  ユーザー名称   */
 , MAILAD   VARCHAR(200)                 NOT NULL                 /* 5  メールアドレス */
 , UPROFILE VARCHAR(4000)                                         /* 6  紹介文         */
 , IMGUSER  VARCHAR(200)                                          /* 7  ユーザー画像   */
 , UPOINT   INTEGER          DEFAULT 0   NOT NULL                 /* 8  ポイント       */
 , UNIQ     SERIAL                                PRIMARY KEY     /* 9  ユニークキー   */
 , FGJ      VARCHAR(1)       DEFAULT '1' NOT NULL                 /* 10 状態フラグ     */
 , DYSET    VARCHAR(14)                                           /* 11 登録日時       */
 , PGSET    VARCHAR(10)                                           /* 12 作成PG         */
 , PGPSET   VARCHAR(10)                                           /* 13 作成親PG       */
 , USRSET   VARCHAR(10)                                           /* 14 作成社員       */
 , DYUPD    VARCHAR(14)                                           /* 15 更新日時       */
 , PGUPD    VARCHAR(10)                                           /* 16 更新PG         */
 , PGPUPD   VARCHAR(10)                                           /* 17 更新親PG       */
 , USRUPD   VARCHAR(10)                                           /* 18 更新者         */
);

==> Iacorner_0.23_dev.zip: an/db/postgres/sql/01_TABLE/AN04S.sql <==
/**************************************************************************/
/* AN04 ( 主催者マスタ )                                                  */
/*                                                                        */
/* Created : 2010/10/08 09:29:32                                          */
/**************************************************************************/
CREATE TABLE AN04 (
   USERID   VARCHAR(10)                  NOT NULL                 /* 1  ユーザーID     */
 , PASSWD   VARCHAR(20)                  NOT NULL                 /* 2  パスワード     */
 , ROLES    VARCHAR(500)                 NOT NULL                 /* 3  ロールズ       */
 , NAME_JA  VARCHAR(500)                 NOT NULL                 /* 4  ユーザー名称   */
 , MAILAD   VARCHAR(200)                 NOT NULL                 /* 5  メールアドレス */
 , UPROFILE VARCHAR(4000)                                         /* 6  プロフィール   */
 , IMGUSER  VARCHAR(200)                                          /* 7  ユーザー画像   */
 , UPOINT   INTEGER          DEFAULT 0   NOT NULL                 /* 8  ポイント       */
 , UNIQ     SERIAL                                PRIMARY KEY     /* 9  ユニークキー   */
 , FGJ      VARCHAR(1)       DEFAULT '1' NOT NULL                 /* 10 状態フラグ     */
 , DYSET    VARCHAR(14)                                           /* 11 登録日時       */
 , PGSET    VARCHAR(10)                                           /* 12 作成PG         */
 , PGPSET   VARCHAR(10)                                           /* 13 作成親PG       */
 , USRSET   VARCHAR(10)                                           /* 14 作成社員       */
 , DYUPD    VARCHAR(14)                                           /* 15 更新日時       */
 , PGUPD    VARCHAR(10)                                           /* 16 更新PG         */
 , PGPUPD   VARCHAR(10)                                           /* 17 更新親PG       */
 , USRUPD   VARCHAR(10)                                           /* 18 更新者         */
);
